"""
CREATE TABLE Сотрудники (
    Табельный_номер INT PRIMARY KEY,
    ФИО TEXT NOT NULL,
    Отдел TEXT NOT NULL,
    Код_должности INT NOT NULL,
    Пол TEXT NOT NULL,
    Дата_рождения DATE NOT NULL,
    Стаж INT NOT NULL,
    Семейное_положение TEXT NOT NULL,
    Дети INT NOT NULL,
    FOREIGN KEY (Код_должности) REFERENCES Штатное_расписание(Код_должности)
);

CREATE TABLE Штатное_расписание (
    Код_должности INT PRIMARY KEY,
    Должность TEXT NOT NULL,
    Оклад INT NOT NULL
);

INSERT INTO Штатное_расписание (Код_должности, Должность, Оклад)
VALUES
    (1, 'Менеджер', 50000),
    (2, 'Инженер', 60000),
    (3, 'Программист', 70000);

INSERT INTO Сотрудники (Табельный_номер, ФИО, Отдел, Код_должности, Пол, Дата_рождения, Стаж, Семейное_положение, Дети)
VALUES
    (1, 'Иванов Иван Иванович', 'Отдел разработки', 3, 'М', '1985-03-15', 8, 'Ж', 2),
    (2, 'Петров Петр Петрович', 'Отдел продаж', 1, 'М', '1990-05-22', 3, 'Х', 0),
    (3, 'Сидорова Елена Владимировна', 'Отдел разработки', 2, 'Ж', '1982-12-07', 12, 'Б', 1),
    (4, 'Ковалева Мария Игоревна', 'Отдел продаж', 1, 'Ж', '1993-07-30', 2, 'Х', 0),
    (5, 'Григорьев Андрей Александрович', 'Отдел разработки', 3, 'М', '1987-11-09', 6, 'Ж', 3),
    (6, 'Николаев Дмитрий Викторович', 'Отдел продаж', 1, 'М', '1995-02-25', 1, 'Х', 0);
Запрос для выборки информации о сотрудниках с их зарплатами в рублях и долларах:
SELECT Сотрудники.Отдел, Сотрудники.ФИО, Штатное_расписание.Оклад*0.8+Штатное_расписание.Оклад AS Зарплата_руб, (Штатное_расписание.Оклад*0.8+Штатное_расписание.Оклад)/73 AS Зарплата_доллар
FROM Сотрудники INNER JOIN Штатное_расписание ON Сотрудники.Код_должности=Штатное_расписание.Код_должности ORDER BY Сотрудники.ФИО;
Запрос для вычисления средней заработной платы, количества женщин и детей по каждому подразделению:
SELECT Сотрудники.Отдел, AVG(Штатное_расписание.Оклад*0.8+Штатное_расписание.Оклад) AS Средняя_зарплата, SUM(IIF(Сотрудники.Пол='Ж',1,0)) AS Количество_женщин, SUM(Сотрудники.Дети) AS Количество_детей FROM Сотрудники INNER JOIN Штатное_расписание ON Сотрудники.Код_должности=Штатное_расписание.Код_должности GROUP BY Сотрудники.Отдел;
"""