"""
:author: GachiParty
"license: Apache License, Version 2.0, see LICENSE file

:copyright: (c) 2023 GachiParty
"""

from .bd1 import *
from .bd2 import *
from .oop1 import *
from .oop2 import *
from .prog1 import *
from .prog2 import *
from .prog3 import *
from .prog4 import *
from .prog5 import *
from .siaod1 import *
from .siaod2 import *

__author__ = 'GachiParty'
__version__ = '1.0a4'
__email__ = 'fetom30268@cutefier.com'